//
//  TDViewController.m
//  TDFace
//
//  Created by Steve Wight on 12/3/12.
//  Copyright (c) 2012 Ziato Labs. All rights reserved.
//

#import "TDViewController.h"

@interface TDViewController ()

-(void)lookForFacesWithImage:(UIImage*)image;

@end

@implementation TDViewController

@synthesize findFace;
@synthesize faceLabel;
@synthesize pickedImageView;
@synthesize faceDetector;

-(IBAction)findFacesInImage:(id)sender {
    
    NSLog(@"Find faces in images has fired");
    self.faceLabel.text = @"Finding Faces ...";
    
    UIActionSheet *pullImageActionSheet = [[UIActionSheet alloc] initWithTitle:@"Pull Photo" delegate:self cancelButtonTitle:@"Nope" destructiveButtonTitle:nil otherButtonTitles:@"Library", nil];
    [pullImageActionSheet showInView:self.view];
    
}

-(void)lookForFacesWithImage:(UIImage*)image {
    
    NSLog(@"lookForFacesInImage method called");
    
}

#pragma mark - UIImagePickerControllerDelegate

-(void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info {
    
    NSLog(@"Did finish picking media with this info: %@",info);
    
    UIImage *pickedImage = [info objectForKey:UIImagePickerControllerOriginalImage];
    self.pickedImageView.image = pickedImage;
    self.faceLabel.text = @"Got it!";
    
    CIImage *imageForAnalysis = [[CIImage alloc] initWithImage:pickedImage];
    
    NSNumber *imgOrientation = [NSNumber numberWithInt:[pickedImage imageOrientation]+1];
    NSDictionary *imgOptions = [NSDictionary dictionaryWithObject:imgOrientation forKey:CIDetectorImageOrientation];
    
    NSArray *foundFeatures = [self.faceDetector featuresInImage:imageForAnalysis options:imgOptions];
    
    int featureCount = [foundFeatures count];
    
    if (featureCount > 0) {
        self.faceLabel.text = [NSString stringWithFormat:@"%d faces found",featureCount];
    } else {
        self.faceLabel.text = @"No Faces Found";
    }
    
    NSLog(@"These are the found features: %@",foundFeatures);
    NSLog(@"CIImage from pickedImage %@",imageForAnalysis);
    
    [self dismissViewControllerAnimated:YES completion:nil];
}

-(void)imagePickerControllerDidCancel:(UIImagePickerController *)picker {
    NSLog(@"Canceled the imagePickerController");
    [self dismissViewControllerAnimated:YES completion:nil];
}


#pragma mark - UIActionSheetDelegate

-(void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {
    
    NSLog(@"The action sheet button has been selected at this position: %d",buttonIndex);
 
    if (buttonIndex == 0) {
        NSLog(@"button zero has been selected: PhotoLibrary");
        
        UIImagePickerController *imagePicker = [[UIImagePickerController alloc] init];
        imagePicker.delegate = self;
        imagePicker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
        
        [self presentViewController:imagePicker animated:YES completion:nil];
        
    } else if (buttonIndex == 1) {
        NSLog(@"button one has been selected: Nope");
    }
    
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    NSDictionary *detectorOptions = [NSDictionary dictionaryWithObjectsAndKeys:CIDetectorAccuracyLow, CIDetectorAccuracy, nil];
    
    self.faceDetector = [CIDetector detectorOfType:CIDetectorTypeFace context:nil options:detectorOptions];
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
